import {
	EyeOutlined,
	LikeOutlined,
	LikeFilled,
	UserOutlined,
	BankOutlined,
	CalendarOutlined,
	FileTextOutlined,
	SendOutlined,
	MailOutlined,
} from "@ant-design/icons";
import { Button, Typography, Space, Tooltip } from "antd";
import { PostDto, PostStateLabels } from "@nice/common";
import dayjs from "dayjs";
import PostLikeButton from "./detail/PostHeader/PostLikeButton";
import { LetterBadge } from "./LetterBadge";
import PostHateButton from "./detail/PostHeader/PostHateButton";
const { Title, Paragraph, Text } = Typography;

interface LetterCardProps {
	letter: PostDto;
}

export function LetterCard({ letter }: LetterCardProps) {
	return (
		<div
			onClick={() => {
				window.open(`/${letter.id}/detail`);
				// console.log(letter);
			}}
			className="cursor-pointer p-6  bg-slate-100/80 rounded-xl  hover:ring-white   hover:ring-1 transition-all 
                     duration-300  ease-in-out hover:-translate-y-0.5
                     active:scale-[0.98]   border  border-white
                     group relative overflow-hidden">
			<div className="flex flex-col gap-4">
				<div className=" text-2xl text-primary  font-bold flex justify-between gap-2">
					<div className="flex items-center gap-2   ">
						<MailOutlined className="" />
						{letter.receivers.some((item) => item?.showname) && (
							<div className="flex items-center gap-2 text-primary-400 ">
								<Tooltip
									title={letter?.receivers
										?.map((item) => `${item?.showname}信箱`)
										.filter(Boolean)
										.join(", ")}>
									<Text className="text-primary-400 text-2xl flex">
										<span>{"[ "}</span>
										{letter.receivers
											.map(
												(item) =>
													`${item?.showname}信箱`
											)
											.filter(Boolean)
											.slice(0, 2)
											.join("、")}
										{letter.receivers.filter(
											(item) => `${item?.showname}信箱`
										).length > 2 && " 等"}
										<span>{" ]"}</span>
									</Text>
								</Tooltip>
							</div>
						)}
						{letter.title}
						{/* 印章样式的"密"字 */}
						{!letter?.isPublic && (
							<div className=" bg-red-600 text-white px-2 py-1 flex justify-center items-center rounded-md text-base font-bold  border-2 border-white shadow-md">
								密
							</div>
						)}
					</div>
				</div>

				{/* Badges & Interactions */}
				<div className="flex justify-between items-center ">
					<div className="flex flex-wrap gap-2">
						<LetterBadge type="state" value={letter.state} />
						{letter.terms.map((term) => (
							<LetterBadge
								key={term.name}
								type="category"
								value={term.name}
							/>
						))}
						<LetterBadge
							type="date"
							value={dayjs(letter.createdAt).format("YYYY-MM-DD")}
						/>
					</div>

					<div className="flex items-center">
						<Button
							type="text"
							shape="round"
							style={{
								color: "#4b5563",
							}}
							icon={<EyeOutlined />}>
							<span className="mr-1">浏览量</span>
							{letter.views}
						</Button>

						<PostHateButton post={letter as any}></PostHateButton>
						<PostLikeButton post={letter as any}></PostLikeButton>
					</div>
				</div>
			</div>
		</div>
	);
}
