import { api, usePost } from "@nice/client";
import {
	Post,
	postDetailSelect,
	PostDto,
	RolePerms,
	UserProfile,
} from "@nice/common";
import { useAuth } from "@web/src/providers/auth-provider";
import React, {
	createContext,
	ReactNode,
	useEffect,
	useMemo,
	useState,
} from "react";
import { PostParams } from "@nice/client/src/singleton/DataHolder";

interface PostDetailContextType {
	editId?: string;
	post?: PostDto;
	isLoading?: boolean;
	user?: UserProfile;
	setKeyCode?: React.Dispatch<React.SetStateAction<string>>;
	canSee?: boolean;
}
interface PostFormProviderProps {
	children: ReactNode;
	editId?: string;
}
export const PostDetailContext = createContext<PostDetailContextType | null>(
	null
);
export function PostDetailProvider({
	children,
	editId,
}: PostFormProviderProps) {
	const { user, hasSomePermissions } = useAuth();

	const postParams = PostParams.getInstance();
	const queryParams = {
		where: { id: editId },
		select: postDetailSelect,
	};
	const [keyCode, setKeyCode] = useState<string>("");
	useEffect(() => {
		if (editId) {
			postParams.addDetailItem(queryParams);
		}
		return () => {
			if (editId) {
				postParams.removeDetailItem(queryParams);
			}
		};
	}, [editId]);

	const { data: post, isLoading }: { data: PostDto; isLoading: boolean } = (
		api.post.findFirst as any
	).useQuery(queryParams, { enabled: Boolean(editId) });
	const canSee = useMemo(() => {
		if (hasSomePermissions(RolePerms.READ_ANY_POST)) {
			return true;
		} else if (
			post?.receivers?.map((receiver) => receiver.id)?.includes(user?.id)
		) {
			return true;
		} else if (!post?.isPublic) {
			if (keyCode === post?.id) {
				return true;
			} else {
				return false;
			}
		} else {
			return true;
		}
	}, [keyCode, post]);
	return (
		<PostDetailContext.Provider
			value={{
				editId,
				post,
				user,
				isLoading,
				canSee,
				setKeyCode,
			}}>
			{children}
		</PostDetailContext.Provider>
	);
}
