import { useState, useCallback, useEffect } from "react";
import { motion, AnimatePresence } from "framer-motion";
import { useSearchParams } from "react-router-dom";

import { Spin, Empty, Input, Alert, Pagination } from "antd";
import { api, useTerm } from "@nice/client";
import DepartmentSelect from "@web/src/components/models/department/department-select";
import debounce from "lodash/debounce";
import { SearchOutlined } from "@ant-design/icons";
// import WriteHeader from "./WriteHeader";
import { RoleName, staffDetailSelect } from "@nice/common";
import { StaffCard } from "@web/src/app/main/letter/list/StaffCard";

export default function SendStaffList() {
	const [currentPage, setCurrentPage] = useState(1);
	const pageSize = 15;
	const { data: enabledStaffIds, isLoading: roleMapIsLoading } =
		api.rolemap.getStaffIdsByRoleNames.useQuery({
			roleNames: [
				RoleName.Leader,
				RoleName.Organization,
				RoleName.RootAdmin,
			],
		});
	const { data, isLoading, error } =
		api.staff.findManyWithPagination.useQuery(
			{
				page: currentPage,
				pageSize,
				select: staffDetailSelect,
				where: {
					id: {
						in: enabledStaffIds?.filter(Boolean),
					},
					deletedAt: null,
				},
				orderBy: {
					order: "asc",
				},
			},
			{
				enabled: !roleMapIsLoading,
			}
		);

	// Reset page when search or department changes

	return (
		<div className="min-h-screen    rounded-xl ">
			{error && (
				<div className="mb-4 space-y-4">
					{
						<Alert
							message="加载失败"
							description="获取数据时出现错误，请刷新页面重试。"
							type="error"
							showIcon
						/>
					}
				</div>
			)}
			<div>
				{isLoading ? (
					<div className="flex justify-center items-center py-12">
						<Spin size="large" tip="加载中..." />
					</div>
				) : data?.items.length > 0 ? (
					<div className="grid grid-cols-1 gap-4 bg-transparent">
						{data?.items.map((item: any) => (
							<StaffCard key={item.id} staff={item} />
						))}
					</div>
				) : (
					<div className="text-center py-12">
						<Empty
							description="没有找到匹配的收信人"
							className="py-12"
						/>
					</div>
				)}
			</div>

			{/* Pagination */}
			{data?.items.length > pageSize && (
				<div className="flex justify-center mt-8">
					<Pagination
						current={currentPage}
						total={data?.totalPages || 0}
						pageSize={pageSize}
						onChange={(page) => {
							setCurrentPage(page);
							window.scrollTo(0, 0);
						}}
						showSizeChanger={false}
						showTotal={(total) => `共 ${total} 条记录`}
					/>
				</div>
			)}
		</div>
	);
}
